{% extends "coop_cms/base.html" %}
{% load i18n %}

{% block meta_title %}
    {% trans "Permission Denied" %}
{% endblock %}

{% block document %}

    <h2>{% trans "Permission Denied" %}</h2>
    
    {% include "coop_cms/_csrf_failure_message.html" %}
    
{% endblock %}
