{% extends "registration/base.html" %}{% load i18n %}
{% block registration_content %}
<h2>{% trans "The password has been changed" %}</h2>
<p>
    {% trans "Login" %} <a href="{% url "login" %}">{% trans "Click Here" %}</a>
</p>
{% endblock %}