{% extends "coop_cms/test_app/base.html" %}
{% load i18n coop_edition %}

{% block content %}
{% cms_edit %}
<div id="content" class="article-content object-detail">
    {% for object in objects %}
    <h2>{{ object.other_field }}</h2>
    <div id="field1">{{ object.field1 }}</div>
    <div id="field2">{{ object.field2 }}</div>
    {% endfor %}
</div>
{% end_cms_edit %}
{% endblock %}